@@ -24,6 +24,7 @@ _logger = logging.getLogger(__name__)
 
 def setup_config(cli_opts):
     ret = {
+        'config': None,
         'user': None,
         'pass': None,
         'url': "http://localhost:8228/v1",
@@ -37,10 +38,18 @@ def setup_config(cli_opts):
 
     settings = {}
 
+    # load environment if present
+    for e in ['ANCHORE_CLI_USER', 'ANCHORE_CLI_PASS', 'ANCHORE_CLI_URL', 'ANCHORE_CLI_HUB_URL', 'ANCHORE_CLI_API_VERSION', 'ANCHORE_CLI_SSL_VERIFY', 'ANCHORE_CLI_JSON', 'ANCHORE_CLI_DEBUG', 'ANCHORE_CLI_ACCOUNT', 'ANCHORE_CLI_CONFIG']:
+        if e in os.environ:
+            settings[e] = os.environ[e]
+
     # load up credentials file if present
     try:
-        home = os.path.expanduser('~')
-        credential_file = os.path.join(home, '.anchore', 'credentials.yaml')
+        if 'ANCHORE_CLI_CONFIG' in settings:
+            credential_file = settings['ANCHORE_CLI_CONFIG']
+        else:
+            home = os.path.expanduser('~')
+            credential_file = os.path.join(home, '.anchore', 'credentials.yaml')
         if os.path.exists(credential_file):
             ydata = {}
             with open(credential_file, 'r') as FH:
@@ -63,12 +72,9 @@ def setup_config(cli_opts):
     except Exception as err:
         raise Exception("error while processing credentials file, please check format and read permissions - exception: " + str(err))
 
-    # load environment if present
-    for e in ['ANCHORE_CLI_USER', 'ANCHORE_CLI_PASS', 'ANCHORE_CLI_URL', 'ANCHORE_CLI_HUB_URL', 'ANCHORE_CLI_API_VERSION', 'ANCHORE_CLI_SSL_VERIFY', 'ANCHORE_CLI_JSON', 'ANCHORE_CLI_DEBUG', 'ANCHORE_CLI_ACCOUNT']:
-        if e in os.environ:
-            settings[e] = os.environ[e]
-
     # load cmdline options
+    if cli_opts['config']:
+        settings['ANCHORE_CLI_CONFIG'] = cli_opts['config']
     if cli_opts['u']:
         settings['ANCHORE_CLI_USER'] = cli_opts['u']
 
@@ -96,6 +102,8 @@ def setup_config(cli_opts):
     if cli_opts.get('as_account') is not None:
         settings['ANCHORE_CLI_ACCOUNT'] = cli_opts['as_account']
 
+    if 'ANCHORE_CLI_CONFIG' in settings:
+        ret['config'] = settings['ANCHORE_CLI_CONFIG']
     if 'ANCHORE_CLI_USER' in settings:
         ret['user'] = settings['ANCHORE_CLI_USER']
     if 'ANCHORE_CLI_PASS' in settings:
@@ -121,7 +129,6 @@ def setup_config(cli_opts):
 
     return ret
 
-
 def doexit(ecode):
     if not os.environ.get('ANCHORE_CLI_NO_FDS_CLEANUP'):
         try:
@@ -329,6 +336,8 @@ def format_output(config, op, params, payload):
                     obuf = obuf + t.get_string(sortby='Package')
                 elif params['query_type'] in ['manifest', 'dockerfile', 'docker_history']:
                     obuf = format_content_query(payload)
+                elif params['query_type'] in ['malware']:
+                    obuf = format_malware_scans(payload, params)
                 else:
                     try:
                         if payload['content']:
@@ -839,20 +848,13 @@ def format_output(config, op, params, payload):
         elif op in ['delete_system_service'] or re.match(".*_delete$", op) or re.match(".*_activate$", op) or re.match(".*_deactivate$", op) or re.match(".*_enable$", op) or re.match(".*_disable$", op):
             # NOTE this should always be the last in the if/elif conditional
             ret = 'Success'
-        elif op in ['analysis_archive_list']:
+        elif op in ['analysis_archive_list', 'archived_analysis']:
             header = ['Digest', 'Tags', 'Analyzed At', 'Archived At', 'Status', 'Archive Size Bytes']
             t = plain_column_table(header)
             for record in payload:
                 row = [str(record['imageDigest']), str(','.join([x['pullstring'] for x in record.get('image_detail', [])])), str(record['analyzed_at']), str(record['created_at']), str(record['status']), str(record['archive_size_bytes'])]
                 t.add_row(row)
             ret = t.get_string(sortby='Archived At', reversesort=True)+"\n"
-        elif op in ['archived_analysis']:
-            header = ['Digest', 'Tags', 'Analyzed At', 'Archived At', 'Status', 'Archive Size Bytes']
-            t = plain_column_table(header)
-            for record in payload:
-                row = [str(record['imageDigest']), str(','.join([x['pullstring'] for x in record.get('image_detail', [])])), str(record['analyzed_at']), str(record['created_at']), str(record['status']), str(record['archive_size_bytes'])]
-                t.add_row(row)
-            ret = t.get_string(sortby='Archived At', reversesort=True) + "\n"
         elif op in ['archive_analysis']:
             header = ['Image Digest', 'Archive Status', 'Details']
             t = plain_column_table(header)
@@ -900,6 +902,59 @@ def format_output(config, op, params, payload):
     return ret
 
 
+def format_malware_scans(payload, params):
+    """
+    Example response:
+    {
+        "content": [
+            {
+                "enabled": true,
+                "findings": [
+                    {
+                        "path": "/elf_payload1",
+                        "signature": "Unix.Trojan.MSShellcode-40"
+                    }
+                ],
+                "metadata": {
+                    "db_version": {
+                        "bytecode": "331",
+                        "daily": "25890",
+                        "main": "59"
+                    }
+                },
+                "scanner": "clamav"
+            }
+        ],
+        "content_type": "malware",
+        "imageDigest": "sha256:0eb874fcad5414762a2ca5b2496db5291aad7d3b737700d05e45af43bad3ce4d"
+    }
+
+    :param payload:
+    :param params:
+    :return:
+    """
+    obuf = ""
+
+    # Handle error
+    if 'query_type' not in params or not params['query_type']:
+        # payload will be a list with what is available as a query for the
+        # given image
+        for query in payload:
+            obuf += "%s: available\n" % query
+        return obuf + "\n"
+
+    if params['query_type'] in ['malware']:
+        header = ['Scanner', 'Matched Signature', 'Path']
+        t = plain_column_table(header)
+        for el in payload['content']:
+            scanner = el.get('scanner')
+            for row in [[scanner, x.get('signature', 'unknown'), x.get('path', 'unknown')] for x in el.get('findings', {})]:
+                t.add_row(row)
+        obuf = obuf + t.get_string(sortby='Path')
+
+    return obuf
+
+
 def format_vulnerabilities(payload, params):
     obuf = ""
     if 'query_type' not in params or not params['query_type']:
